SyncDBCache class

Constructors

SyncDBCache(String id, String uid, String collection, String entityId, String diffJson, String newJson, String operation, {DateTime? createdAt})

Properties

changes → Stream
no setter
collection ↔ String
getter/setter pair
createdAt ↔ DateTime?
getter/setter pair
diffJson ↔ String
getter/setter pair
entityId ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String
getter/setter pair
newJson ↔ String
getter/setter pair
objectSchema → dynamic
no setter
operation ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uid ↔ String
getter/setter pair

Methods

changesFor([List<String>? keyPaths]) → Stream
freeze() → SyncDBCache
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toEJson() → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

schema → dynamic
final