HistoricChangesResult class

Result summary for a historic change fetch.

Constructors

HistoricChangesResult({required String collectionName, required int requestedSince, required int latestTimestamp, required int appliedCount, required int skippedCount, required List<String> appliedIds, required List<Map<String, dynamic>> rawChanges})

Properties

appliedCount → int
final
appliedIds → List<String>
final
collectionName → String
final
hashCode → int
The hash code for this object.
no setterinherited
latestTimestamp → int
final
rawChanges → List<Map<String, dynamic>>
final
requestedSince → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skippedCount → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited